import { Construct, IConstruct } from "constructs";
/**
 * @stability stable
 */
export interface IParent extends IConstruct {
    /**
     * The unique identifier (ID) of the parent root or organizational unit (OU) that you want to create the new OU in.
     *
     * @stability stable
     */
    identifier(): string;
}
/**
 * @stability stable
 */
export interface IChild extends IConstruct {
    /**
     * The unique identifier (ID) of the account or organizational unit (OU) that you want to retrieve the parent for.
     *
     * @stability stable
     */
    identifier(): string;
}
/**
 * @stability stable
 */
export interface ParentProps {
    /**
     * @stability stable
     */
    readonly child: IChild;
}
/**
 * @stability stable
 */
export interface ParentBaseProps {
    /**
     * @stability stable
     */
    readonly childId: string;
}
/**
 * @stability stable
 */
export declare abstract class ParentBase extends Construct implements IParent {
    /**
     * @stability stable
     */
    readonly parentId: string;
    /**
     * @stability stable
     */
    protected constructor(scope: Construct, id: string, props: ParentBaseProps);
    /**
     * The unique identifier (ID) of the parent root or organizational unit (OU) that you want to create the new OU in.
     *
     * @stability stable
     */
    identifier(): string;
}
/**
 * @stability stable
 */
export declare class Parent extends ParentBase {
    /**
     * @stability stable
     */
    static fromChildId(scope: Construct, id: string, childId: string): IParent;
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, props: ParentProps);
}
